@@ -10,7 +10,7 @@ only if a new data is available.
 
 """
 
-__version__ = "1.1.3"
+__version__ = "1.1.4"
 
 import argparse
 import logging
@@ -25,14 +25,12 @@ import matplotlib.dates as mdates
 import matplotlib.pyplot as plt
 import requests
 
-from PIL import Image, ImageDraw, ImageFont
 from slack_sdk import WebClient
 from slack_sdk.errors import SlackApiError
 
 NOAA_URL = 'https://services.swpc.noaa.gov'
 ALERTS_URL = NOAA_URL + "/text/wwv.txt"
 FLUX_URL = NOAA_URL + "/text/27-day-outlook.txt"
-MUF_URL = NOAA_URL + '/products/animations/wam-ipe/ionosphere.json'
 
 CACHE_DIR = "/tmp/sunslack-data"
 FONT_PATH = "/System/Library/Fonts/Supplemental/Arial.ttf"
@@ -126,32 +124,6 @@ class NoaaData:
     return self.date == other.date
 
 
-class MUF:
-  """Store and manage a MUF record"""
-  __slots__ = ['time', 'filename', 'path', 'new_flag']
-
-  def __init__(self, new_flag, filename):
-    self.new_flag = new_flag
-    self.filename = os.path.basename(filename)
-    self.path = os.path.dirname(filename)
-    name = os.path.splitext(filename)[0]
-    self.time = datetime.strptime(name.split('_')[-1], '%Y%m%dT%H%M')
-
-  def __repr__(self):
-    return f"{self.time} {self.filename}"
-
-  @property
-  def fullname(self):
-    return os.path.join(self.path, self.filename)
-
-  @property
-  def strdate(self):
-    return self.time.strftime("%Y %b %d %H:%M UTC")
-
-  def is_new(self):
-    return self.new_flag
-
-
 class SunRecord:
   """Datastructure holding the sun Flux information"""
   __slots__ = ("date", "data")
@@ -284,70 +256,6 @@ class Alerts:
     return '\n'.join(f for f in self.data.fields if not f.startswith('No space weather'))
 
 
-class MUFPredictions:
-  """Download the metadata and files necessary for generating the MUF animation map"""
-
-  def __init__(self, cache_dir):
-    os.makedirs(cache_dir, exist_ok=True)
-    self.cache_dir = cache_dir
-    self.muf_data = []
-    self.newdata = False
-    try:
-      req = requests.get(MUF_URL)
-      data = req.json()
-    except requests.ConnectionError as err:
-      logging.error("Connection error: %s let's try later", err)
-      sys.exit(os.EX_IOERR)
-
-    if req.status_code == 200:
-      for item in data:
-        filename = item['url']
-        self.muf_data.append(MUF(*download_image(filename, cache_dir)))
-    logging.info('%d images to be processed', len(self.muf_data))
-
-    # check if we have any new data
-    for mufinfo in self.muf_data:
-      if mufinfo.is_new():
-        self.newdata = True
-
-  def __repr__(self):
-    return '<MUFPredictions> {:d} files, new data {}'.format(len(self.muf_data), self.newdata)
-
-  def gen_animation(self, filename, font):
-    """Geneate the MUF animation"""
-    font = ImageFont.truetype(font, 16)
-
-    image_list = []
-    for num, mufdata in enumerate(self.muf_data):
-      if num % 2 != 0:          # We only animage one every two images
-        continue
-      logging.debug('%d, %s', num, mufdata.filename)
-      image = Image.open(mufdata.fullname)
-      image = image.crop((800, 50, 1550, 430))
-      image = image.resize((640, 330))
-      draw = ImageDraw.Draw(image)
-      draw.text((25, 305), mufdata.strdate, (255, 255, 255), font=font)
-      image_list.append(image)
-    image_list[0].save(filename, save_all=True, optimize=True, duration=100, loop=0,
-                       append_images=image_list[1:])
-    logging.info('Animation %s generated', filename)
-
-
-  def cleanup(self):
-    """Remove the older MUF files"""
-    newfiles = {f.filename for f in self.muf_data}
-    if not newfiles:            # Ignore cleanup when we have no new files.
-      return
-    currentfiles = {n for n in os.listdir(self.cache_dir) if n.startswith('WFS_IPE')}
-    for name in currentfiles ^ ( newfiles & currentfiles):
-      try:
-        filename = os.path.join(self.cache_dir, name)
-        os.unlink(filename)
-        logging.debug('Removing: %s', filename)
-      except IOError as err:
-        logging.warning(err)
-
-
 def readcache(cachefile):
   """Read data from the cache"""
   try:
@@ -457,26 +365,18 @@ def get_flux(config, client):
 
 
 def get_muf(config, client):
-  muf = MUFPredictions(config.cachedir)
-  if not muf.newdata:
-    logging.info('No new MUF graph to post')
+  # The muf video animation is generated by the animatemuf.py program
+  muf_video = '/var/www/html/muf.mp4'
+  # muf_video = '/Volumes/WDPassport/tmp/muf/muf.mp4'
+  if not os.path.exists(muf_video):
     return
-
-  time_tag = datetime.now().strftime('%Y%m%d%H%M')
-  anim_file = 'MUF_{}.png'.format(time_tag)
-  anim_file = os.path.join(config.cachedir, anim_file)
-  logging.info('A new animated map %s generated', anim_file)
-  muf.gen_animation(filename=anim_file, font=config.font)
   try:
-    title = "MUF Predictions _click on the image to see the animation_"
-    client.files_upload(file=anim_file, channels=config.channel, initial_comment=title)
-    logging.info("Sending muf animation file: %s", anim_file)
+    title = "MUF for the last 24 hours _click on the image to see the animation_"
+    client.files_upload(file=muf_video, channels=config.channel, initial_comment=title)
+    logging.info("Sending muf animation file: %s", muf_video)
   except SlackApiError as err:
     logging.error("file_upload error: %s", err.response['error'])
 
-  # cleanup the MUF cache
-  muf.cleanup()
-
 
 def main():
   # pylint: disable=too-many-statements
